'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactAsync = require("react-async");

var _components = require("./components.js");

function _interopRequireDefault(obj) {
  return obj && obj.__esModule ? obj : {
    "default": obj
  };
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _objectSpread(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    var ownKeys = Object.keys(source);

    if (typeof Object.getOwnPropertySymbols === 'function') {
      ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) {
        return Object.getOwnPropertyDescriptor(source, sym).enumerable;
      }));
    }

    ownKeys.forEach(function (key) {
      _defineProperty(target, key, source[key]);
    });
  }

  return target;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

var state = {
  intercept: window.sessionStorage.getItem("intercept") === "true",
  latency: window.sessionStorage.getItem("latency") || "0",
  update: function update() {}
};
window.__REACT_ASYNC__ = window.__REACT_ASYNC__ || {};

window.__REACT_ASYNC__.devToolsDispatcher = function (action, dispatch) {
  var run = function run() {
    dispatch(action);
    state.update(action);
  };

  switch (action.type) {
    case _reactAsync.actionTypes.start:
      if (state.intercept) {
        dispatch(_objectSpread({}, action, {
          payload: undefined
        }));
        state.update(action, run);
      } else run();

      break;

    case _reactAsync.actionTypes.fulfill:
    case _reactAsync.actionTypes.reject:
      setTimeout(run, state.latency * 1000);
      break;

    default:
      run();
  }
};

var DevTools = function DevTools() {
  var _React$useState = _react["default"].useState({}),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      instances = _React$useState2[0],
      setInstances = _React$useState2[1];

  var _React$useState3 = _react["default"].useState(state.intercept),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      interceptState = _React$useState4[0],
      setIntercept = _React$useState4[1];

  var intercept = _react["default"].useRef(interceptState);

  var _React$useState5 = _react["default"].useState(state.latency),
      _React$useState6 = _slicedToArray(_React$useState5, 2),
      latencyState = _React$useState6[0],
      setLatency = _React$useState6[1];

  var delay = _react["default"].useRef(latencyState * 1000);

  state.update = function (action, run) {
    var label = action.meta.debugLabel;
    setInstances(function (instances) {
      return _objectSpread({}, instances, _defineProperty({}, label, {
        label: label,
        state: (0, _reactAsync.reducer)(instances[label], action),
        run: run
      }));
    });
  };

  var updateLatency = function updateLatency(event) {
    window.sessionStorage.setItem("latency", event.target.value);
    delay.current = event.target.value * 1000;
    state.latency = event.target.value;
    setLatency(event.target.value);
  };

  var updateIntercept = function updateIntercept(event) {
    window.sessionStorage.setItem("intercept", event.target.checked ? "true" : "false");
    state.intercept = event.target.checked;
    intercept.current = event.target.checked;
    setIntercept(event.target.checked);
  };

  var states = Object.keys(instances).map(function (label) {
    return instances[label];
  });
  var pending = states.filter(function (_ref) {
    var state = _ref.state;
    return state.status === "pending";
  });
  var fulfilled = states.filter(function (_ref2) {
    var state = _ref2.state;
    return state.status === "fulfilled";
  });
  var rejected = states.filter(function (_ref3) {
    var state = _ref3.state;
    return state.status === "rejected";
  });
  return _react["default"].createElement(_components.Root, null, _react["default"].createElement(_components.Label, null, "Latency:", " ", _react["default"].createElement("b", null, latencyState, " ", latencyState === "1" ? "second" : "seconds"), _react["default"].createElement(_components.Range, {
    max: "5",
    value: latencyState,
    onChange: updateLatency
  })), _react["default"].createElement(_components.Label, null, _react["default"].createElement(_components.Checkbox, {
    checked: interceptState,
    onChange: updateIntercept
  }), "Pause new requests"), pending.length > 0 && _react["default"].createElement("section", null, _react["default"].createElement(_components.Small, null, "Pending"), _react["default"].createElement(_components.Ol, null, pending.map(function (_ref4, index) {
    var label = _ref4.label,
        run = _ref4.run;
    return _react["default"].createElement(_components.Li, {
      key: index
    }, label, " ", run && _react["default"].createElement(_components.Button, {
      onClick: run
    }, "run"));
  }))), fulfilled.length > 0 && _react["default"].createElement("section", null, _react["default"].createElement(_components.Small, null, "Fulfilled"), _react["default"].createElement(_components.Ol, null, fulfilled.map(function (promise, index) {
    return _react["default"].createElement(_components.Li, {
      key: index
    }, promise.label);
  }))), rejected.length > 0 && _react["default"].createElement("section", null, _react["default"].createElement(_components.Small, null, "Rejected"), _react["default"].createElement(_components.Ol, null, rejected.map(function (promise, index) {
    return _react["default"].createElement(_components.Li, {
      key: index
    }, promise.label);
  }))));
};

var _default = DevTools;
exports["default"] = _default;
